@@ -124,9 +124,7 @@ pub enum DO {
     CreateSchema(String),
     CreateFunction(ObjRef, Rc<String>, bool),
     AlterTable(ObjRef, Vec<AlterAction>),
-    RenameSchema(String, String),
     RenameTable(ObjRef, ObjRef),
-    RenameFunction(ObjRef, ObjRef),
     DropSchema(String),
     DropTable(ObjRef),
     DropIndex(ObjRef, String),
